# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API ChartAxisLabelPosition <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart.html#a693b6b549818a6055effeaf72501bd26>`_
"""

NEAR_AXIS: 'uno.Enum'
"""
The labels are placed adjacent to the axis.

When the axis itself is placed at the minimum or maximum of the scale ( that is when the property CrossoverPosition equals ChartAxisPosition_MINIMUM or ChartAxisPosition_MAXIMUM) the labels are placed outside the coordinate system. Otherwise the labels are placed adjacent to the axis on that side that belongs to the lower values on the crossing axis. E.g. when the ChartAxisLabelPosition is set to NEAR_AXIS for an y axis the labels are placed adjacent to the y axis on that side that belongs to the lower x values.
"""
NEAR_AXIS_OTHER_SIDE: 'uno.Enum'
"""
The labels are placed adjacent to the axis on the opposite side as for NEAR_AXIS.
"""
OUTSIDE_END: 'uno.Enum'
"""
The labels are placed outside the coordinate region on that side where the crossing axis has its maximum value.

E.g. when this is set for an y axis the labels are placed outside the diagram on that side where to the x axis has its maximum value.
"""
OUTSIDE_START: 'uno.Enum'
"""
The labels are placed outside the coordinate region on that side where the crossing axis has its minimum value.

E.g. when this is set for an y axis the labels are placed outside the diagram on that side where to the x axis has its minimum value.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.animations
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .x_animation_node import XAnimationNode as XAnimationNode_1cf10eb9

class XAnimationListener(XEventListener_c7230c4a):
    """
    makes it possible to register listeners, which are called whenever an animation event occurs.
    
    **since**
    
        OOo 3.0

    See Also:
        `API XAnimationListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XAnimationListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.animations.XAnimationListener']

    def beginEvent(self, Node: 'XAnimationNode_1cf10eb9') -> None:
        """
        This event is raised when the element local timeline begins to play.
        
        It will be raised each time the element begins the active duration (i.e. when it restarts, but not when it repeats).
        
        It may be raised both in the course of normal (i.e. scheduled or interactive) timeline play, as well as in the case that the element was begun with an interface method.
        """
    def endEvent(self, Node: 'XAnimationNode_1cf10eb9') -> None:
        """
        This event is raised at the active end of the element.
        
        Note that this event is not raised at the simple end of each repeat.
        
        This event may be raised both in the course of normal (i.e. scheduled or interactive) timeline play, as well as in the case that the element was ended with a DOM method.
        """
    def repeat(self, Node: 'XAnimationNode_1cf10eb9', Repeat: int) -> None:
        """
        This event is raised when the element local timeline repeats.
        
        It will be raised each time the element repeats, after the first iteration.
        
        Associated with the repeat event is an integer that indicates which repeat iteration is beginning.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..geometry.affine_matrix2_d import AffineMatrix2D as AffineMatrix2D_ff040da8
from .color_component import ColorComponent as ColorComponent_e4c0e78
from .x_poly_polygon2_d import XPolyPolygon2D as XPolyPolygon2D_e1b0e20


class RenderState(object):
    """
    Struct Class

    This structure contains information passed to each XCanvas render operation.
    
    This structure contains information considered as the render state, i.e. the common setup required to render each individual XCanvas primitive.
    
    **since**
    
        OOo 2.0

    See Also:
        `API RenderState <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1RenderState.html>`_
    """
    typeName: Literal['com.sun.star.rendering.RenderState']

    def __init__(self, DeviceColor: typing.Optional[typing.Tuple[ColorComponent_e4c0e78, ...]] = ..., AffineTransform: typing.Optional[AffineMatrix2D_ff040da8] = ..., Clip: typing.Optional[XPolyPolygon2D_e1b0e20] = ..., CompositeOperation: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            DeviceColor (typing.Tuple[ColorComponent, ...], optional): DeviceColor value.
            AffineTransform (AffineMatrix2D, optional): AffineTransform value.
            Clip (XPolyPolygon2D, optional): Clip value.
            CompositeOperation (int, optional): CompositeOperation value.
        """


    @property
    def DeviceColor(self) -> typing.Tuple[ColorComponent_e4c0e78, ...]:
        """
        The device color associated with this render operation.
        
        Note that this need not be RGB here, but depends on the active device color space.
        """


    @property
    def AffineTransform(self) -> AffineMatrix2D_ff040da8:
        """
        The affine transform associated with this render operation.
        
        This is used to transform coordinates of canvas primitives from user space to view space (from which they are subsequently transformed to device space by the view transform).
        """


    @property
    def Clip(self) -> XPolyPolygon2D_e1b0e20:
        """
        The clipping area associated with this render operation.
        
        This clipping is interpreted in the user coordinate system, i.e. subject to the render state transform followed by the view transform before mapped to device coordinate space.
        
        Specifying an empty interface denotes no clipping, i.e. everything rendered to the canvas will be visible (subject to device-dependent constraints, of course). Specifying an empty XPolyPolygon2D, i.e. a poly-polygon containing zero polygons, or an XPolyPolygon2D with any number of empty sub-polygons, denotes the NULL clip. That means, nothing rendered to the canvas will be visible.
        """


    @property
    def CompositeOperation(self) -> int:
        """
        The composition mode associated with this render operation.
        
        The composite mode determines in which way the primitive and possibly existing background is combined. The permissible values must be one out of the CompositeOperation constants.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .device_info import DeviceInfo as DeviceInfo_8e370a30
    from .font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from .x_bitmap import XBitmap as XBitmap_70cd0909
    from .x_display_bitmap import XDisplayBitmap as XDisplayBitmap_bb550bdf
    from .x_font import XFont as XFont_5f480843
    from .x_graphics import XGraphics as XGraphics_842309dd

class XDevice(XInterface_8f010a43):
    """
    provides information about a graphical output device and offers a factory for the graphics which provides write operations on the device.

    See Also:
        `API XDevice <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XDevice.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XDevice']

    def createBitmap(self, nX: int, nY: int, nWidth: int, nHeight: int) -> 'XBitmap_70cd0909':
        """
        creates a bitmap with the current device depth.
        
        If the specified area does not lie entirely in the device, the bits outside are not specified.
        """
    def createDevice(self, nWidth: int, nHeight: int) -> 'XDevice':
        """
        creates a new device which is compatible with this one.
        
        If the device does not support the GETBITS device capability, this method returns NULL.
        """
    def createDisplayBitmap(self, Bitmap: 'XBitmap_70cd0909') -> 'XDisplayBitmap_bb550bdf':
        """
        creates a device compatible bitmap.
        
        The data of the bitmap is in process memory instead of in the device, so that the output operation is fast.
        """
    def createGraphics(self) -> 'XGraphics_842309dd':
        """
        creates a new graphics whose output operation is directed to this device.
        """
    def getFont(self, aDescriptor: 'FontDescriptor_bc110c0a') -> 'XFont_5f480843':
        """
        returns information about a font offered by this device.
        """
    def getFontDescriptors(self) -> 'typing.Tuple[FontDescriptor_bc110c0a, ...]':
        """
        returns the list of available font descriptors.
        """
    def getInfo(self) -> 'DeviceInfo_8e370a30':
        """
        returns information about the device.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.logging
import typing
from .x_log_handler import XLogHandler as XLogHandler_c7f80c27
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3

class FileHandler(XLogHandler_c7f80c27):
    """
    Service Class

    specifies a component implementing a log handler whose output channel is a file.
    
    The handler will use the Encoding attribute of XLogHandler to determine how to encode strings before actually writing them to the output file.
    
    **since**
    
        OOo 2.3

    See Also:
        `API FileHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1logging_1_1FileHandler.html>`_
    """
    def create(self, FileURL: str) -> None:
        """
        creates a log handler whose output is directed to a file given by URL.
        """
    def createWithSettings(self, Settings: 'typing.Tuple[NamedValue_a37a0af3, ...]') -> None:
        """
        creates an instance of the log handler, using generic settings
        
        The following settings are recognized and supported:
        
        Additionally, a setting name FileURL is recognized. It must be of type string, and denotes the file URL to which the handler's output should be directed.
        
        At least the URL argument must be present in the settings.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API ClickAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8f>`_
"""

BOOKMARK: 'uno.Enum'
"""
The presentation jumps to a bookmark.
"""
DOCUMENT: 'uno.Enum'
"""
The presentation jumps to another document.
"""
FIRSTPAGE: 'uno.Enum'
"""
The presentation continues with the first page.
"""
INVISIBLE: 'uno.Enum'
"""
The object renders itself invisible after a click.
"""
LASTPAGE: 'uno.Enum'
"""
The presentation continues with the last page.
"""
MACRO: 'uno.Enum'
"""
A star basic macro is executed after the click.
"""
NEXTPAGE: 'uno.Enum'
"""
The presentation jumps to the next page.
"""
NONE: 'uno.Enum'
"""
use no animation effects.

use no fade effects.

No action is performed on click.
"""
PREVPAGE: 'uno.Enum'
"""
The presentation jumps to the previous page.
"""
PROGRAM: 'uno.Enum'
"""
Another program is executed after a click.
"""
SOUND: 'uno.Enum'
"""
A sound is played after a click.
"""
STOPPRESENTATION: 'uno.Enum'
"""
The presentation is stopped after the click.
"""
VANISH: 'uno.Enum'
"""
The object vanishes with its effect.
"""
VERB: 'uno.Enum'
"""
An OLE verb is performed on this object.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.packages.zip
from .x_zip_file_access2 import XZipFileAccess2 as XZipFileAccess2_45470f57

class ZipFileAccess(XZipFileAccess2_45470f57):
    """
    Service Class

    allows to get reading access to non-encrypted entries inside zip file.

    See Also:
        `API ZipFileAccess <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1packages_1_1zip_1_1ZipFileAccess.html>`_
    """
    def createWithURL(self, URL: str) -> None:
        """

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.ucb.ContentCreationException: ``ContentCreationException``
            com.sun.star.ucb.InteractiveIOException: ``InteractiveIOException``
            com.sun.star.packages.zip.ZipException: ``ZipException``
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
import typing
from .x_poly_polygon2_d import XPolyPolygon2D as XPolyPolygon2D_e1b0e20
if typing.TYPE_CHECKING:
    from ..geometry.real_bezier_segment2_d import RealBezierSegment2D as RealBezierSegment2D_4a970fa2

class XBezierPolyPolygon2D(XPolyPolygon2D_e1b0e20):
    """
    This is a specialized interface for a 2D poly-polygon containing straight line and Bezier segments.
    
    This poly-polygon can contain polygons consisting of a mixture of cubic Bezier curves and straight lines. As the straight line is a special case of a cubic Bezier curve (control points collinear with the line through start and end point), this can be expressed uniformly with a sequence of RealBezierSegment2Ds.
    
    By convention, a RealBezierSegment2D is a straight line segment, if all three contained points are strictly equal.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XBezierPolyPolygon2D <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XBezierPolyPolygon2D.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rendering.XBezierPolyPolygon2D']

    def getBezierSegment(self, nPolygonIndex: int, nPointIndex: int) -> 'RealBezierSegment2D_4a970fa2':
        """
        Get a single point from the poly-polygon.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getBezierSegments(self, nPolygonIndex: int, nNumberOfPolygons: int, nPointIndex: int, nNumberOfPoints: int) -> 'typing.Tuple[typing.Tuple[RealBezierSegment2D_4a970fa2, ...], ...]':
        """
        Query subset of this poly-polygon.
        
        Query subset of this poly-polygon, starting at the given polygon and the given point within that polygon, and containing the specified number of polygons and points in the last polygon.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setBezierSegment(self, point: 'RealBezierSegment2D_4a970fa2', nPolygonIndex: int, nPointIndex: int) -> None:
        """
        Set a single point on the poly-polygon.
        
        The remaining points of the poly-polygon will not be changed by this method. Use XBezierPolyPolygon2D.getNumberOfPolygons() or XBezierPolyPolygon2D.getNumberOfPolygonPoints() to append points or polygons, respectively.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setBezierSegments(self, points: 'typing.Tuple[typing.Tuple[RealBezierSegment2D_4a970fa2, ...], ...]', nPolygonIndex: int) -> None:
        """
        Set the specified sequence of Bezier segments to the poly-polygon.
        
        This method can either set the whole poly-polygon to the new data, or insert the segments at the given index

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ..._pyi.form.binding.bindable_control_model import BindableControlModel as BindableControlModel
from ..._pyi.form.binding.bindable_data_aware_control_model import BindableDataAwareControlModel as BindableDataAwareControlModel
from ..._pyi.form.binding.bindable_database_check_box import BindableDatabaseCheckBox as BindableDatabaseCheckBox
from ..._pyi.form.binding.bindable_database_combo_box import BindableDatabaseComboBox as BindableDatabaseComboBox
from ..._pyi.form.binding.bindable_database_date_field import BindableDatabaseDateField as BindableDatabaseDateField
from ..._pyi.form.binding.bindable_database_formatted_field import BindableDatabaseFormattedField as BindableDatabaseFormattedField
from ..._pyi.form.binding.bindable_database_list_box import BindableDatabaseListBox as BindableDatabaseListBox
from ..._pyi.form.binding.bindable_database_numeric_field import BindableDatabaseNumericField as BindableDatabaseNumericField
from ..._pyi.form.binding.bindable_database_radio_button import BindableDatabaseRadioButton as BindableDatabaseRadioButton
from ..._pyi.form.binding.bindable_database_text_field import BindableDatabaseTextField as BindableDatabaseTextField
from ..._pyi.form.binding.bindable_database_time_field import BindableDatabaseTimeField as BindableDatabaseTimeField
from ..._pyi.form.binding.bindable_integer_value_range import BindableIntegerValueRange as BindableIntegerValueRange
from ..._pyi.form.binding.incompatible_types_exception import IncompatibleTypesException as IncompatibleTypesException
from ..._pyi.form.binding.invalid_binding_state_exception import InvalidBindingStateException as InvalidBindingStateException
from ..._pyi.form.binding.list_entry_event import ListEntryEvent as ListEntryEvent
from ..._pyi.form.binding.list_entry_source import ListEntrySource as ListEntrySource
from ..._pyi.form.binding.value_binding import ValueBinding as ValueBinding
from ..._pyi.form.binding.x_bindable_value import XBindableValue as XBindableValue
from ..._pyi.form.binding.x_list_entry_listener import XListEntryListener as XListEntryListener
from ..._pyi.form.binding.x_list_entry_sink import XListEntrySink as XListEntrySink
from ..._pyi.form.binding.x_list_entry_source import XListEntrySource as XListEntrySource
from ..._pyi.form.binding.x_list_entry_typed_source import XListEntryTypedSource as XListEntryTypedSource
from ..._pyi.form.binding.x_value_binding import XValueBinding as XValueBinding



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.bridge
from .ole_bridge_supplier2 import OleBridgeSupplier2 as OleBridgeSupplier2_18030e68

class OleBridgeSupplierVar1(OleBridgeSupplier2_18030e68):
    """
    Service Class

    maps UNO types to COM types and vice versa.
    
    It is optimized for use in a remote scenario.
    
    The functionality is basically the same as com.sun.star.bridge.OleBridgeSupplier2. However, the implementation should be optimized for remote access. For example, it could try to reduce the calls into the remote process. Also it could create components on its own behalf in the remote process, if this increases performance.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API OleBridgeSupplierVar1 <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1OleBridgeSupplierVar1.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.drawing.framework
from typing_extensions import Literal
import typing
from .x_configuration_controller_broadcaster import XConfigurationControllerBroadcaster as XConfigurationControllerBroadcaster_5e871a2e
from .x_configuration_controller_request_queue import XConfigurationControllerRequestQueue as XConfigurationControllerRequestQueue_7a5d1ab2
from .x_resource_factory_manager import XResourceFactoryManager as XResourceFactoryManager_3eb91523
if typing.TYPE_CHECKING:
    from .resource_activation_mode import ResourceActivationMode as ResourceActivationMode_2b5e14cf
    from .x_configuration import XConfiguration as XConfiguration_8f0511a0
    from .x_resource import XResource as XResource_3bcd0f90
    from .x_resource_id import XResourceId as XResourceId_5be3103d

class XConfigurationController(XConfigurationControllerBroadcaster_5e871a2e, XConfigurationControllerRequestQueue_7a5d1ab2, XResourceFactoryManager_3eb91523):
    """
    The configuration controller is responsible for the management of the set of active resources.
    
    There are two configurations of resources:
    
    When the two configurations differ then the current configuration is updated eventually to reflect the requested configuration. An update takes place when the following three conditions are fulfilled.
    
    Requests for configuration changes are handled in a two step process:
    
    The configuration controller sends the following events:

    See Also:
        `API XConfigurationController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfigurationController.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.drawing.framework.XConfigurationController']

    def getCurrentConfiguration(self) -> 'XConfiguration_8f0511a0':
        """
        Return a copy of the current configuration.
        
        Modifications to the returned configuration have no effect on the drawing framework.
        """
    def getRequestedConfiguration(self) -> 'XConfiguration_8f0511a0':
        """
        Return a copy of the requested configuration.
        
        Modifications to the returned configuration have no effect on the drawing framework.
        """
    def getResource(self, xResourceId: 'XResourceId_5be3103d') -> 'XResource_3bcd0f90':
        """
        Return the active resource specified by the given resource id.
        """
    def lock(self) -> None:
        """
        Lock the processing of configuration change requests.
        
        This is only necessary when more than one change request is being made in a row. It prevents an update being made (with all the visible UI changes) before all change requests are being made.
        
        Recursive lock() calls are recognized: the configuration controller is locked while lock() was called more often than unlock().
        """
    def requestResourceActivation(self, xResourceId: 'XResourceId_5be3103d', eMode: 'ResourceActivationMode_2b5e14cf') -> None:
        """
        Request the activation of a resource.
        
        The request is processed asynchronously. Notifications about configuration changes are sent after this call returns.
        
        When eMode is REPLACE then, before adding the resource activation to the request queue, similar resources linked to the same anchor are removed. This makes it easier to switch between resources whose activation is mutually exclusive. For example, there can only be one view per pane, so before activating a new view the old one has to be deactivated.
        
        When eMode is ADD then the resource is requested without further changes.
        """
    def requestResourceDeactivation(self, xResourceId: 'XResourceId_5be3103d') -> None:
        """
        Request the deactivation of a resource.
        
        The request is processed asynchronously. Notifications about configuration changes are sent after this call returns.
        
        Requesting the deactivation of a resource that is not active is not an error.
        """
    def restoreConfiguration(self, xConfiguration: 'XConfiguration_8f0511a0') -> None:
        """
        Replace the requested configuration with the given configuration and schedule an update of the current configuration.
        
        Together with the getCurrentConfiguration() and getRequestedConfiguration() methods this allows the saving and restoring of configurations. However, the given configuration can have other origins then these methods.
        
        The given configuration is transformed into a list of change requests so that the resulting requested configuration equals the given configuration. This has the advantage that not only the resource activations and deactivations but all configuration changes are properly broadcasted.
        
        Note that because of the configuration change notifications listeners can make more configuration change requests, so that the resulting requested configuration can be different from the given configuration.
        """
    def unlock(self) -> None:
        """
        Unlock the processing of configuration change requests.
        
        When unlock() is called as many times as lock() and the queue of configuration change requests is not empty the configuration controller continues the processing of the change requests. An update of the current configuration will eventually being made.
        """
    def update(self) -> None:
        """
        Explicitly request an update of the current configuration.
        
        Call it when a resource is activated or deactivated without the control and knowledge of the drawing framework. Calling this method (from outside the drawing framework) should hardly every be necessary.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_area_link import XAreaLink as XAreaLink_98db0a80
from ..util.x_refreshable import XRefreshable as XRefreshable_b0d60b81

class CellAreaLink(XPropertySet_bc180bfa, XAreaLink_98db0a80, XRefreshable_b0d60b81):
    """
    Service Class

    represents a linked cell range.
    
    A linked cell range is a range which is linked to an equal-sized range in an external document. The contents of the external range is copied into the range of this document.
    
    **since**
    
        OOo 2.0

    See Also:
        `API CellAreaLink <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink.html>`_
    """
    @property
    def Filter(self) -> str:
        """
        specifies the name of the filter used to load the source document.
        """
    @property
    def FilterOptions(self) -> str:
        """
        specifies the filter options needed to load the source document.
        """
    @property
    def RefreshDelay(self) -> int:
        """
        specifies the delay time between two refresh actions in seconds.
        """
    @property
    def RefreshPeriod(self) -> int:
        """
        specifies the time between two refresh actions in seconds.
        
        **since**
        
            OOo 2.0
        """
    @property
    def Url(self) -> str:
        """
        specifies the URL of the source document.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from typing_extensions import Literal


class ControlCharacter(object):
    """
    Const

    These constants are the codes for inserting control characters using XSimpleText.insertControlCharacter() interface.

    See Also:
        `API ControlCharacter <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1text_1_1ControlCharacter.html>`_
    """
    PARAGRAPH_BREAK: Literal[0]
    """
    This control character starts a new paragraph.
    """
    LINE_BREAK: Literal[1]
    """
    This control character starts a new line in a paragraph.
    """
    HARD_HYPHEN: Literal[2]
    """
    This control character equals a dash but prevents this position from being hyphenated.
    """
    SOFT_HYPHEN: Literal[3]
    """
    This control character defines a special position as a hyphenation point.
    
    If a word containing a soft hyphen must be split at the end of a line, then this position is preferred.
    """
    HARD_SPACE: Literal[4]
    """
    This control character is used to link two words and prevents this concatenation from being hyphenated.
    
    It is printed as a space.
    """
    APPEND_PARAGRAPH: Literal[5]
    """
    This control character appends a new paragraph.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.beans
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XPropertyContainer(XInterface_8f010a43):
    """
    makes it possible to add and remove properties to or from an object.
    
    Some scripting engines cannot access properties directly when the property set is changed. Please use XPropertySet.getPropertyValue() etc. in this case.

    See Also:
        `API XPropertyContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XPropertyContainer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.beans.XPropertyContainer']

    def addProperty(self, Name: str, Attributes: int, DefaultValue: object) -> None:
        """
        adds a property to the object.

        Raises:
            com.sun.star.beans.PropertyExistException: ``PropertyExistException``
            com.sun.star.beans.IllegalTypeException: ``IllegalTypeException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def removeProperty(self, Name: str) -> None:
        """
        removes a property from the object.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.beans.NotRemoveableException: ``NotRemoveableException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.packages.zip
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...io.x_input_stream import XInputStream as XInputStream_98d40ab4

class XZipFileAccess(XInterface_8f010a43):
    """
    allows to get reading access to non-encrypted entries inside zip file.

    See Also:
        `API XZipFileAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1packages_1_1zip_1_1XZipFileAccess.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.packages.zip.XZipFileAccess']

    def getStreamByPattern(self, aPattern: str) -> 'XInputStream_98d40ab4':
        """
        allows to get stream by specifying a pattern.
        
        The first stream with a name that fits to the pattern will be returned. The pattern allows to use \"*\" wildcard symbol. If the name contains \"*\" or \"\\\" symbols itself they must guarded with backslash \"\\\". The slashes have no special meaning here so they can be replaced by wildcards also.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.packages.zip.ZipException: ``ZipException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.document
from abc import ABC

class EventDescriptor(ABC):
    """
    Service Class

    specifies an event binding for a document or a document content

    See Also:
        `API EventDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1document_1_1EventDescriptor.html>`_
    """
    @property
    def EventType(self) -> str:
        """
        specifies the type of the event handler
        
        Usually this is one of the following:
        
        This list is extensible.
        """
    @property
    def Script(self) -> str:
        """
        specifies the script source code
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ui.dialogs
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ...beans.string_pair import StringPair as StringPair_a4bc0b14

class XFilterGroupManager(XInterface_8f010a43):
    """
    Specifies an interface which allows manipulation of groups of filters for the FilePicker service.

    See Also:
        `API XFilterGroupManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilterGroupManager.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.dialogs.XFilterGroupManager']

    def appendFilterGroup(self, sGroupTitle: str, aFilters: 'typing.Tuple[StringPair_a4bc0b14, ...]') -> None:
        """
        Appends a group of filters to the current filter list.
        
        It is implementation dependent how the filter groups are presented to the user.
        It is not even guaranteed that the groups are visualized: implementations are free to simply append all the filters separately, with ignoring the group title.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal


class ImageScaleMode(object):
    """
    Const

    defines modes how an image displayed in a given area should be scaled to fit this area

    See Also:
        `API ImageScaleMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1ImageScaleMode.html>`_
    """
    NONE: Literal[0]
    """
    specifies that no scaling should happen at all
    """
    ISOTROPIC: Literal[1]
    """
    specifies that the image should be scaled up or down to the size of the surrounding area isotropically, i.e.
    
    by keeping its aspect ratio.
    """
    ANISOTROPIC: Literal[2]
    """
    specifies that the image should be scaled up or down to the size of the surrounding area anisotropically.
    
    The image will finally cover all of the surrounding area, but its dimensions might be distorted.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.datatransfer.dnd
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..x_transferable import XTransferable as XTransferable_2d800f38
    from .drag_gesture_event import DragGestureEvent as DragGestureEvent_9e7211ca
    from .x_drag_source_listener import XDragSourceListener as XDragSourceListener_d56f12f8

class XDragSource(XInterface_8f010a43):
    """
    This interface is implemented by a view or window that supports drag operations and will be received as part of a DragGestureEvent through a com.sun.star.datatransfer.dnd.XDragGestureListener.dragGestureRecognized() callback.
    
    Differently to Java, the association between view and interface is fixed and can not be changed. Otherwise, the AWT messaging would have to be implemented for any window supporting Drag and Drop operations, which would be a real performance issue.

    See Also:
        `API XDragSource <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSource.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.datatransfer.dnd.XDragSource']

    def getDefaultCursor(self, dragAction: int) -> int:
        """
        To get the default cursor for a specified drag action.
        
        The returned value may be used as parameter for the method com.sun.star.datatransfer.dnd.XDragSourceContext.setCursor().

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def isDragImageSupported(self) -> bool:
        """
        In order to query if drag image support is available.
        """
    def startDrag(self, trigger: 'DragGestureEvent_9e7211ca', sourceActions: int, cursor: int, image: int, trans: 'XTransferable_2d800f38', listener: 'XDragSourceListener_d56f12f8') -> None:
        """
        Starts the drag operation.
        
        Note: this call does not block until the drag and drop operation ends. If the Drag and Drop system is unable to initiate a drag operation or if the user attempts to start a drag while an existing drag operation is still executing, the action fails immediately. This is indicated by calling com.sun.star.datatransfer.dnd.XDragSourceListener.dragDropEnd() on the parameter listener with a DragSourceDragEvent showing a failure.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart2
from typing_extensions import Literal
import typing
from .data.x_data_provider import XDataProvider as XDataProvider_122f0e31
if typing.TYPE_CHECKING:
    from .data.x_data_sequence import XDataSequence as XDataSequence_11f00e1f

class XInternalDataProvider(XDataProvider_122f0e31):
    """
    An internal DataProvider that has more access to data than a plain DataProvider.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XInternalDataProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XInternalDataProvider.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.chart2.XInternalDataProvider']

    def appendSequence(self) -> None:
        """
        same as insertSequence with nAfterIndex being the largest current index of the data, i.e.
        
        (size - 1)
        """
    def deleteComplexCategoryLevel(self, nLevel: int) -> None:
        """
        deletes an additional sequence for categories at nLevel>=1; categories at level 0 are always present and cannot be deleted
        
        **since**
        
            OOo 3.3
        """
    def deleteDataPointForAllSequences(self, nAtIndex: int) -> None:
        """
        """
    def deleteSequence(self, nAtIndex: int) -> None:
        """
        """
    def getDataByRangeRepresentation(self, aRange: str) -> 'typing.Tuple[object, ...]':
        """
        """
    def hasDataByRangeRepresentation(self, aRange: str) -> bool:
        """
        """
    def insertComplexCategoryLevel(self, nLevel: int) -> None:
        """
        insert an additional sequence for categories nLevel>=1; categories at level 0 are always present and cannot be inserted or deleted
        
        **since**
        
            OOo 3.3
        """
    def insertDataPointForAllSequences(self, nAfterIndex: int) -> None:
        """
        """
    def insertSequence(self, nAfterIndex: int) -> None:
        """
        """
    def registerDataSequenceForChanges(self, xSeq: 'XDataSequence_11f00e1f') -> None:
        """
        If range representations of data sequences change due to internal structural changes, they must be registered at the data provider.
        
        Sequences that are directly retrieved via the methods of the XDataProvider interface are already registered. If a labeled data sequence was created by cloning an existing one, it has to be explicitly registered via this method.
        """
    def setDataByRangeRepresentation(self, aRange: str, aNewData: 'typing.Tuple[object, ...]') -> None:
        """
        """
    def swapDataPointWithNextOneForAllSequences(self, nAtIndex: int) -> None:
        """
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart
from ..drawing.shape import Shape as Shape_85cc09e5
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222

class ChartTitle(Shape_85cc09e5, UserDefinedAttributesSupplier_9fbe1222):
    """
    Service Class

    specifies titles in a chart.
    
    In a chart there may be the following titles: the main title, the sub title, and axis titles of the x- and y-axis.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API ChartTitle <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartTitle.html>`_
    """
    @property
    def AutomaticPosition(self) -> bool:
        """
        If this property is TRUE the position is calculated by the application automatically.
        
        Setting this property to false will have no effect. Instead use the interface com.sun.star.drawing.XShape to set a concrete position.
        """
    @property
    def String(self) -> str:
        """
        contains the text of the title.
        
        Note that you cannot change attributes of parts of a title, e.g., put one word in bold characters. All formatting affects the entire string.
        """
    @property
    def TextRotation(self) -> int:
        """
        specifies the rotation of the shape in 100th of degrees.
        
        Especially in three-dimensional charts, this property comes in handy if you want to align the axis titles with the axis, which are usually not vertical or horizontal in the two-dimensional projection.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.util
from typing_extensions import Literal
import typing
from .x_text_search import XTextSearch as XTextSearch_a56a0b19
if typing.TYPE_CHECKING:
    from .search_options2 import SearchOptions2 as SearchOptions2_c94e0c3a

class XTextSearch2(XTextSearch_a56a0b19):
    """
    enables an object to search in its content.
    
    Derived from com.sun.star.util.XTextSearch this interface adds simple wildcard search capabilities using com.sun.star.util.SearchOptions2 options.
    
    **since**
    
        LibreOffice 5.2

    See Also:
        `API XTextSearch2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XTextSearch2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.util.XTextSearch2']

    def setOptions2(self, options: 'SearchOptions2_c94e0c3a') -> None:
        """
        set the options for the forward or backward search.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal


class EmphasisMark(object):
    """
    Const

    These constants control the automatic rendering of emphasis marks.
    
    These constants control the automatic rendering of emphasis marks for a given font.
    
    **since**
    
        OOo 2.0

    See Also:
        `API EmphasisMark <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1EmphasisMark.html>`_
    """
    NONE: Literal[0]
    """
    No automatic emphasis marks.
    """
    DOT_ABOVE: Literal[1]
    """
    Automatic emphasis marks as dots above the glyphs.
    """
    DOT_BELOW: Literal[2]
    """
    Automatic emphasis marks as dots below the glyphs.
    """
    CIRCLE_ABOVE: Literal[3]
    """
    Automatic emphasis marks as circles (unfilled outlines) above the glyphs.
    """
    CIRCLE_BELOW: Literal[4]
    """
    Automatic emphasis marks as circles (unfilled outlines) below the glyphs.
    """
    DISC_ABOVE: Literal[5]
    """
    Automatic emphasis marks as discs (filled circles) above the glyphs.
    """
    DISC_BELOW: Literal[6]
    """
    Automatic emphasis marks as discs (filled circles) below the glyphs.
    """
    ACCENT_ABOVE: Literal[7]
    """
    Automatic emphasis marks as accent marks above the glyphs.
    """
    ACCENT_BELOW: Literal[8]
    """
    Automatic emphasis marks as accent marks below the glyphs.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.report
from typing_extensions import Literal
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_child import XChild as XChild_a6390b07
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from .x_functions_supplier import XFunctionsSupplier as XFunctionsSupplier_1ee10f09
if typing.TYPE_CHECKING:
    from .x_groups import XGroups as XGroups_90d00a7c
    from .x_section import XSection as XSection_9b630ad1

class XGroup(XPropertySet_bc180bfa, XChild_a6390b07, XComponent_98dc0ab5, XFunctionsSupplier_1ee10f09):
    """
    identifies a XGroup.
    
    A group is always a child of the groups collection in the report.

    See Also:
        `API XGroup <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XGroup.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.report.XGroup']

    @property
    def Expression(self) -> str:
        """
        Defines either a column name or an expression.
        """

    @property
    def Footer(self) -> 'XSection_9b630ad1':
        """
        returns the group footer.
        """

    @property
    def FooterOn(self) -> bool:
        """
        Defines if a group has a footer.
        """

    @property
    def GroupInterval(self) -> int:
        """
        Defines an interval value that rows are grouped by.
        """

    @property
    def GroupOn(self) -> int:
        """
        Specifies how to group data.
        """

    @property
    def Groups(self) -> 'XGroups_90d00a7c':
        """
        Specifies the parent of the group.
        """

    @property
    def Header(self) -> 'XSection_9b630ad1':
        """
        returns the group header.
        """

    @property
    def HeaderOn(self) -> bool:
        """
        Defines if a group has a header.
        """

    @property
    def KeepTogether(self) -> int:
        """
        Specifies if a group header, detail, and footer section is printed on the same page.
        """

    @property
    def ResetPageNumber(self) -> bool:
        """
        Specifies that the group header should always be printed on a new page and the reset of the page number to zero.
        """

    @property
    def SortAscending(self) -> bool:
        """
        Defines if the group is sorted ascending or descending.
        
        The default is TRUE.
        """

    @property
    def StartNewColumn(self) -> bool:
        """
        Specifies that the group header should always be printed on a new column.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt.grid
from typing_extensions import Literal
import typing
from ...lang.x_component import XComponent as XComponent_98dc0ab5
from ...util.x_cloneable import XCloneable as XCloneable_99d00aa3
if typing.TYPE_CHECKING:
    from .x_grid_column_listener import XGridColumnListener as XGridColumnListener_44350fba
    from ...style.horizontal_alignment import HorizontalAlignment as HorizontalAlignment_1f800f02

class XGridColumn(XComponent_98dc0ab5, XCloneable_99d00aa3):
    """
    The XGridColumn defines the properties and behavior of a column in a grid control.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XGridColumn <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridColumn.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.grid.XGridColumn']

    def addGridColumnListener(self, Listener: 'XGridColumnListener_44350fba') -> None:
        """
        Adds a listener for the GridColumnEvent posted after the grid changes.
        """
    def removeGridColumnListener(self, Listener: 'XGridColumnListener_44350fba') -> None:
        """
        Removes a listener previously added with addColumnListener().
        """
    @property
    def ColumnWidth(self) -> int:
        """
        specifies the current width of the column.
        """

    @property
    def DataColumnIndex(self) -> int:
        """
        denotes the index of the data column which should be used to fetch this grid column's data
        
        A grid control has a column model and a data model, both containing a possibly different number of columns. The DataColumnIndex attribute defines the index of the column within the data model, which should be used to retrieve actual data.
        
        Using this, you can do runtime changes to the column model, i.e. insertion and removal of columns, without necessarily needing to adjust the data model, too.
        
        If DataColumnIndex is negative, the it will be ignored, then the column's index within its column model, as determined by the Index attribute, will be used.
        """

    @property
    def Flexibility(self) -> int:
        """
        specifies the flexibility of the column when it is automatically resized due to the grid control as a whole being resized.
        
        Specify 0 here if you do not want the column to be resized automatically.
        
        If a column has a flexibility greater than 0, it is set in relationship to the flexibility of all other such columns, and the respective widths of the columns are changed in the same relationship.
        
        Note that a column's flexibility is ignored if its Resizeable attribute is FALSE.
        
        A column's flexibility cannot be negative, attempts to set a negative value will raise an exception.
        """

    @property
    def HelpText(self) -> str:
        """
        is the help text associated with the column.
        
        A grid control will usually display a column's help text as tooltip.
        """

    @property
    def HorizontalAlign(self) -> 'HorizontalAlignment_1f800f02':
        """
        Specifies the horizontal alignment of the content in the control.
        """

    @property
    def Identifier(self) -> object:
        """
        specifies an identifier of the column
        
        This identifier will not be evaluated by the grid control, or its model. It is merely for clients to identify particular columns.
        """

    @property
    def Index(self) -> int:
        """
        denotes the index of the column within the grid column model it belongs to
        
        If the column is not yet part of a column model, Index is -1.
        """

    @property
    def MaxWidth(self) -> int:
        """
        specifies the maximal width the column can have.
        """

    @property
    def MinWidth(self) -> int:
        """
        specifies the minimal width the column can have.
        """

    @property
    def Resizeable(self) -> bool:
        """
        controls whether or not the column's width is fixed or not.
        
        If this is TRUE, the user can interactively change the column's width. Also, the column is subject to auto-resizing, if its Flexibility attribute is greater 0.
        """

    @property
    def Title(self) -> str:
        """
        A title is displayed in the column header row if UnoControlGridModel.ShowColumnHeader() is set to TRUE
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.mozilla
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class MenuMultipleChange(object):
    """
    Struct Class

    Explains properties of a menu item.

    See Also:
        `API MenuMultipleChange <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1mozilla_1_1MenuMultipleChange.html>`_
    """
    typeName: Literal['com.sun.star.mozilla.MenuMultipleChange']

    def __init__(self, Image: typing.Optional[typing.Tuple[int, ...]] = ..., ID: typing.Optional[int] = ..., GroupID: typing.Optional[int] = ..., PreItemID: typing.Optional[int] = ..., ItemText: typing.Optional[str] = ..., IsVisible: typing.Optional[bool] = ..., IsActive: typing.Optional[bool] = ..., IsCheckable: typing.Optional[bool] = ..., IsChecked: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            Image (typing.Tuple[int, ...], optional): Image value.
            ID (int, optional): ID value.
            GroupID (int, optional): GroupID value.
            PreItemID (int, optional): PreItemID value.
            ItemText (str, optional): ItemText value.
            IsVisible (bool, optional): IsVisible value.
            IsActive (bool, optional): IsActive value.
            IsCheckable (bool, optional): IsCheckable value.
            IsChecked (bool, optional): IsChecked value.
        """


    @property
    def Image(self) -> typing.Tuple[int, ...]:
        """
        sequence of bytes representing a possible image
        """


    @property
    def ID(self) -> int:
        """
        unique ID of this menu item
        """


    @property
    def GroupID(self) -> int:
        """
        unique ID of the group this menu item belongs to
        """


    @property
    def PreItemID(self) -> int:
        """
        unique ID of the item directly above this menu item, used for fuzzy placement
        """


    @property
    def ItemText(self) -> str:
        """
        text of the menu item
        """


    @property
    def IsVisible(self) -> bool:
        """
        true if visible
        """


    @property
    def IsActive(self) -> bool:
        """
        true if active, so clickable
        """


    @property
    def IsCheckable(self) -> bool:
        """
        true if checkable, so there can be a checkmark
        """


    @property
    def IsChecked(self) -> bool:
        """
        true if there is a checkmark
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt.tree
from typing_extensions import Literal
import typing
from ...lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .tree_data_model_event import TreeDataModelEvent as TreeDataModelEvent_349a0f2f

class XTreeDataModelListener(XEventListener_c7230c4a):
    """
    An instance of this interface is used by the TreeControl to get notifications about data model changes.
    
    Usually you must not implement this interface yourself as it is already handled by the TreeControl, but you must notify it correctly if you implement the XTreeDataModel yourself
    
    .

    See Also:
        `API XTreeDataModelListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModelListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.tree.XTreeDataModelListener']

    def treeNodesChanged(self, Event: 'TreeDataModelEvent_349a0f2f') -> None:
        """
        Invoked after a node (or a set of siblings) has changed in some way.
        
        The node(s) have not changed locations in the tree or altered their children arrays, but other attributes have changed and may affect presentation.
        
        Example: the name of a file has changed, but it is in the same location in the file system.
        
        To indicate the root has changed, TreeDataModelEvent.Nodes will contain the root node and TreeDataModelEvent.ParentNode will be empty.
        """
    def treeNodesInserted(self, Event: 'TreeDataModelEvent_349a0f2f') -> None:
        """
        Invoked after nodes have been inserted into the tree.
        
        Use TreeDataModelEvent.ParentNode to get the parent of the new node(s). TreeDataModelEvent.Nodes contains the new node(s).
        """
    def treeNodesRemoved(self, Event: 'TreeDataModelEvent_349a0f2f') -> None:
        """
        Invoked after nodes have been removed from the tree.
        
        Note that if a subtree is removed from the tree, this method may only be invoked once for the root of the removed subtree, not once for each individual set of siblings removed.
        
        Use TreeDataModelEvent.ParentNode to get the former parent of the deleted node(s). TreeDataModelEvent.Nodes contains the removed node(s).
        """
    def treeStructureChanged(self, Event: 'TreeDataModelEvent_349a0f2f') -> None:
        """
        Invoked after the tree has drastically changed structure from a given node down.
        
        Use TreeDataModelEvent.ParentNode to get the node which structure has changed. TreeDataModelEvent.Nodes is empty.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.task
# Libre Office Version: 7.2
from .x_job_executor import XJobExecutor as XJobExecutor_af4e0b7d


class theJobExecutor(XJobExecutor_af4e0b7d):
    """
    Singleton Class

    Generic job execution singleton.
    
    Can start registered uno services on triggered events and handle there own configuration and there lifetime. Such events are simple strings which meaning doesn't matter for any real service implementation of this specification. But triggered events must be available inside the configuration and some Jobs or AsyncJobs must be registered for that.
    
    Prior to LibreOffice 4.3, this singleton was only available as a (single-instance) JobExecutor service.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API theJobExecutor <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1task_1_1theJobExecutor.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.packages
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..io.x_output_stream import XOutputStream as XOutputStream_a4e00b35

class XPackageEncryption(XInterface_8f010a43):
    """
    Allows to transparently plug-in crypto for PackageStreams.
    
    **since**
    
        LibreOffice 7.0

    See Also:
        `API XPackageEncryption <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1packages_1_1XPackageEncryption.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.packages.XPackageEncryption']

    def checkDataIntegrity(self) -> bool:
        """
        Check if decryption meta data is valid.
        
        Some implementations might for example check HMAC values here. Call this before trusting encrypted data.
        """
    def createEncryptionData(self, rPassword: str) -> 'typing.Tuple[NamedValue_a37a0af3, ...]':
        """
        Create key-value list of encryption meta data.
        
        After generateEncryptionKey() succeeded in setting up crypto, use this method to create requisite meta data. Depending on underlying crypto, this can be a salt, init vector, or other algorithm-specific information that needs to be stored alongside an encrypted document
        """
    def decrypt(self, rxInputStream: 'XInputStream_98d40ab4', rxOutputStream: 'XOutputStream_a4e00b35') -> bool:
        """
        Decrypt document content.
        
        After crypto setup via readEncryptionInfo(), pipe package bits through encryption engine.

        * ``rxOutputStream`` is an out direction argument.
        """
    def encrypt(self, rxInputStream: 'XInputStream_98d40ab4') -> 'typing.Tuple[NamedValue_a37a0af3, ...]':
        """
        Encrypt given stream.
        
        After setting up crypto via setupEncryption(), use this method to encrypt content.
        """
    def generateEncryptionKey(self, rPassword: str) -> bool:
        """
        Set or refresh encryption key.
        """
    def readEncryptionInfo(self, rStreams: 'typing.Tuple[NamedValue_a37a0af3, ...]') -> bool:
        """
        Read package crypto information.
        """
    def setupEncryption(self, rMediaEncData: 'typing.Tuple[NamedValue_a37a0af3, ...]') -> bool:
        """
        Set key-value list of encryption meta data.
        
        Use this method to setup requisite encryption meta data. Depending on the underlying crypto, this can be a salt, init vector, or other algorithm-specific information that needs to be stored alongside an encrypted document
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6
    from .x_remote_content_provider_done_listener import XRemoteContentProviderDoneListener as XRemoteContentProviderDoneListener_fc7413f8

class XRemoteContentProviderAcceptor(XInterface_8f010a43):
    """
    Accept remote content providers that want to make themselves known to the local process.

    See Also:
        `API XRemoteContentProviderAcceptor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ucb_1_1XRemoteContentProviderAcceptor.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ucb.XRemoteContentProviderAcceptor']

    def addRemoteContentProvider(self, Identifier: str, Factory: 'XMultiServiceFactory_191e0eb6', Templates: 'typing.Tuple[str, ...]', DoneListener: 'XRemoteContentProviderDoneListener_fc7413f8') -> bool:
        """
        Add a remote content provider.
        
        To enable connection control, it is recommended that this argument also implements the interface XRemoteContentProviderConnectionControl.
        """
    def removeRemoteContentProvider(self, Identifier: str) -> bool:
        """
        Remove a remote content provider.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form.component
import typing
from ...awt.uno_control_button_model import UnoControlButtonModel as UnoControlButtonModel_1c000ed4
from ..form_control_model import FormControlModel as FormControlModel_e2990d22
from ..x_image_producer_supplier import XImageProducerSupplier as XImageProducerSupplier_37df0f8f
from ..x_reset import XReset as XReset_71670917
if typing.TYPE_CHECKING:
    from ..form_button_type import FormButtonType as FormButtonType_c92d0c6e

class CommandButton(UnoControlButtonModel_1c000ed4, FormControlModel_e2990d22, XImageProducerSupplier_37df0f8f, XReset_71670917):
    """
    Service Class

    specifies the control model for a clickable button which is part of a form component hierarchy.

    See Also:
        `API CommandButton <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1CommandButton.html>`_
    """
    @property
    def ButtonType(self) -> 'FormButtonType_c92d0c6e':
        """
        describes the action to be executed by the button when pressed.
        """
    @property
    def DefaultState(self) -> bool:
        """
        specifies the default toggle state for the button, used when it is reset.
        
        This property is meaningful only when com.sun.star.awt.UnoControlButtonModel.Toggle is TRUE. In this case, the DefaultState controls to which State the button will be reset.
        
        For a given implementation of the interface, if this (optional) property is present, then also the optional interface com.sun.star.form.XReset must be present.
        """
    @property
    def TargetFrame(self) -> str:
        """
        describes the frame, where to open the document specified by the TargetURL.
        
        This property is evaluated if the button is of type URL.
        
        As always, there is a number of target names which have a special meaning, and force a special com.sun.star.frame.Frame to be used.
        """
    @property
    def TargetURL(self) -> str:
        """
        specifies the URL, which should be opened if the button was clicked.
        
        This property is evaluated if the button is of type URL.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.script
import typing
from .x_storage_based_library_container import XStorageBasedLibraryContainer as XStorageBasedLibraryContainer_d72a1321
if typing.TYPE_CHECKING:
    from ..document.x_storage_based_document import XStorageBasedDocument as XStorageBasedDocument_6b1310b2

class DocumentDialogLibraryContainer(XStorageBasedLibraryContainer_d72a1321):
    """
    Service Class

    defines a container of dialog libraries, which is to be made persistent in a sub storage of a document storage.
    
    **since**
    
        OOo 2.3

    See Also:
        `API DocumentDialogLibraryContainer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1script_1_1DocumentDialogLibraryContainer.html>`_
    """
    def create(self, Document: 'XStorageBasedDocument_6b1310b2') -> None:
        """
        creates an instance of the DocumentDialogLibraryContainer, belonging to a document
        
        The current storage of the document will be set as initial root storage (see XPersistentLibraryContainer.RootStorage) of the container.
        
        Usually, you will only create a DocumentDialogLibraryContainer within the implementation of the document to which the container should belong.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def createWithURL(self, URL: str) -> None:
        """
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdbc
from typing_extensions import Literal
"""
Const

describes the different scroll capabilities of a result set.

See Also:
    `API ResultSetType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdbc_1_1ResultSetType.html>`_
"""
FORWARD_ONLY: Literal[1003]
"""
is the type for a com.sun.star.sdb.ResultSet object whose cursor may move only forward.
"""
SCROLL_INSENSITIVE: Literal[1004]
"""
is the type for a com.sun.star.sdb.ResultSet object that is scrollable but generally not sensitive to changes made by others.
"""
SCROLL_SENSITIVE: Literal[1005]
"""
is the type for a com.sun.star.sdb.ResultSet object that is scrollable and generally sensitive to changes made by others.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rdf
from typing_extensions import Literal


class URIs(object):
    """
    Const

    Constants to specify some well-known URIs.
    
    These constants are for use with URI.createKnown().
    
    **since**
    
        OOo 3.2

    See Also:
        `API URIs <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rdf_1_1URIs.html>`_
    """
    XSD_NCNAME: Literal[1]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#NCName
    """
    XSD_STRING: Literal[2]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#string
    """
    XSD_NORMALIZEDSTRING: Literal[3]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#normalizedString
    """
    XSD_BOOLEAN: Literal[4]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#boolean
    """
    XSD_DECIMAL: Literal[5]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#decimal
    """
    XSD_FLOAT: Literal[6]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#float
    """
    XSD_DOUBLE: Literal[7]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#double
    """
    XSD_INTEGER: Literal[8]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#integer
    """
    XSD_NONNEGATIVEINTEGER: Literal[9]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#nonNegativeInteger
    """
    XSD_POSITIVEINTEGER: Literal[10]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#positiveInteger
    """
    XSD_NONPOSITIVEINTEGER: Literal[11]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#nonPositiveInteger
    """
    XSD_NEGATIVEINTEGER: Literal[12]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#negativeInteger
    """
    XSD_LONG: Literal[13]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#long
    """
    XSD_INT: Literal[14]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#int
    """
    XSD_SHORT: Literal[15]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#short
    """
    XSD_BYTE: Literal[16]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#byte
    """
    XSD_UNSIGNEDLONG: Literal[17]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#unsignedLong
    """
    XSD_UNSIGNEDINT: Literal[18]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#unsignedInt
    """
    XSD_UNSIGNEDSHORT: Literal[19]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#unsignedShort
    """
    XSD_UNSIGNEDBYTE: Literal[20]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#unsignedByte
    """
    XSD_HEXBINARY: Literal[21]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#hexBinary
    """
    XSD_BASE64BINARY: Literal[22]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#base64Binary
    """
    XSD_DATETIME: Literal[23]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#dateTime
    """
    XSD_TIME: Literal[24]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#time
    """
    XSD_DATE: Literal[25]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#date
    """
    XSD_GYEARMONTH: Literal[26]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#gYearMonth
    """
    XSD_GYEAR: Literal[27]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#gYear
    """
    XSD_GMONTHDAY: Literal[28]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#gMonthDay
    """
    XSD_GDAY: Literal[29]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#gDay
    """
    XSD_GMONTH: Literal[30]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#gMonth
    """
    XSD_ANYURI: Literal[31]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#anyURI
    """
    XSD_TOKEN: Literal[32]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#token
    """
    XSD_LANGUAGE: Literal[33]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#language
    """
    XSD_NMTOKEN: Literal[34]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#NMTOKEN
    """
    XSD_NAME: Literal[35]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#Name
    """
    XSD_DURATION: Literal[36]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#duration
    """
    XSD_QNAME: Literal[37]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#QName
    """
    XSD_NOTATION: Literal[38]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#NOTATION
    """
    XSD_NMTOKENS: Literal[39]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#NMTOKENS
    """
    XSD_ID: Literal[40]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#ID
    """
    XSD_IDREF: Literal[41]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#IDREF
    """
    XSD_IDREFS: Literal[42]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#IDREFS
    """
    XSD_ENTITY: Literal[43]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#ENTITY
    """
    XSD_ENTITIES: Literal[44]
    """
    http://www.w3.org/2001/XMLSchema-datatypes#ENTITIES
    """
    RDF_TYPE: Literal[1000]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#type
    """
    RDF_SUBJECT: Literal[1001]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#subject
    """
    RDF_PREDICATE: Literal[1002]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#predicate
    """
    RDF_OBJECT: Literal[1003]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#object
    """
    RDF_PROPERTY: Literal[1004]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#Property
    """
    RDF_STATEMENT: Literal[1005]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#Statement
    """
    RDF_VALUE: Literal[1006]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#value
    """
    RDF_FIRST: Literal[1007]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#first
    """
    RDF_REST: Literal[1008]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#rest
    """
    RDF_NIL: Literal[1009]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#nil
    """
    RDF_XMLLITERAL: Literal[1010]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral
    """
    RDF_ALT: Literal[1011]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#Alt
    """
    RDF_BAG: Literal[1012]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#Bag
    """
    RDF_LIST: Literal[1013]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#List
    """
    RDF_SEQ: Literal[1014]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#Seq
    """
    RDF_1: Literal[1015]
    """
    http://www.w3.org/1999/02/22-rdf-syntax-ns#_1
    """
    RDFS_COMMENT: Literal[1100]
    """
    http://www.w3.org/2000/01/rdf-schema#comment
    """
    RDFS_LABEL: Literal[1101]
    """
    http://www.w3.org/2000/01/rdf-schema#label
    """
    RDFS_DOMAIN: Literal[1102]
    """
    http://www.w3.org/2000/01/rdf-schema#domain
    """
    RDFS_RANGE: Literal[1103]
    """
    http://www.w3.org/2000/01/rdf-schema#range
    """
    RDFS_SUBCLASSOF: Literal[1104]
    """
    http://www.w3.org/2000/01/rdf-schema#subClassOf
    """
    RDFS_LITERAL: Literal[1105]
    """
    http://www.w3.org/2000/01/rdf-schema#Literal
    """
    RDFS_MEMBER: Literal[1106]
    """
    http://www.w3.org/2000/01/rdf-schema#member
    """
    RDFS_SUBPROPERTYOF: Literal[1107]
    """
    http://www.w3.org/2000/01/rdf-schema#subPropertyOf
    """
    RDFS_ISDEFINEDBY: Literal[1108]
    """
    http://www.w3.org/2000/01/rdf-schema#isDefinedBy
    """
    RDFS_SEEALSO: Literal[1109]
    """
    http://www.w3.org/2000/01/rdf-schema#seeAlso
    """
    RDFS_RESOURCE: Literal[1110]
    """
    http://www.w3.org/2000/01/rdf-schema#Resource
    """
    RDFS_CLASS: Literal[1111]
    """
    http://www.w3.org/2000/01/rdf-schema#Class
    """
    RDFS_DATATYPE: Literal[1112]
    """
    http://www.w3.org/2000/01/rdf-schema#Datatype
    """
    RDFS_CONTAINER: Literal[1113]
    """
    http://www.w3.org/2000/01/rdf-schema#Container
    """
    RDFS_CONTAINERMEMBERSHIPPROPERTY: Literal[1114]
    """
    http://www.w3.org/2000/01/rdf-schema#ContainerMembershipProperty
    """
    OWL_CLASS: Literal[1200]
    """
    http://www.w3.org/2002/07/owl#Class
    """
    OWL_OBJECTPROPERTY: Literal[1201]
    """
    http://www.w3.org/2002/07/owl#ObjectProperty
    """
    OWL_DATATYPEPROPERTY: Literal[1202]
    """
    http://www.w3.org/2002/07/owl#DatatypeProperty
    """
    OWL_FUNCTIONALPROPERTY: Literal[1203]
    """
    http://www.w3.org/2002/07/owl#FunctionalProperty
    """
    OWL_THING: Literal[1204]
    """
    http://www.w3.org/2002/07/owl#Thing
    """
    OWL_NOTHING: Literal[1205]
    """
    http://www.w3.org/2002/07/owl#Nothing
    """
    OWL_INDIVIDUAL: Literal[1206]
    """
    http://www.w3.org/2002/07/owl#Individual
    """
    OWL_EQUIVALENTCLASS: Literal[1207]
    """
    http://www.w3.org/2002/07/owl#equivalentClass
    """
    OWL_EQUIVALENTPROPERTY: Literal[1208]
    """
    http://www.w3.org/2002/07/owl#equivalentProperty
    """
    OWL_SAMEAS: Literal[1209]
    """
    http://www.w3.org/2002/07/owl#sameAs
    """
    OWL_DIFFERENTFROM: Literal[1210]
    """
    http://www.w3.org/2002/07/owl#differentFrom
    """
    OWL_ALLDIFFERENT: Literal[1211]
    """
    http://www.w3.org/2002/07/owl#AllDifferent
    """
    OWL_DISTINCTMEMBERS: Literal[1212]
    """
    http://www.w3.org/2002/07/owl#distinctMembers
    """
    OWL_INVERSEOF: Literal[1213]
    """
    http://www.w3.org/2002/07/owl#inverseOf
    """
    OWL_TRANSITIVEPROPERTY: Literal[1214]
    """
    http://www.w3.org/2002/07/owl#TransitiveProperty
    """
    OWL_SYMMETRICPROPERTY: Literal[1215]
    """
    http://www.w3.org/2002/07/owl#SymmetricProperty
    """
    OWL_INVERSEFUNCTIONALPROPERTY: Literal[1216]
    """
    http://www.w3.org/2002/07/owl#InverseFunctionalProperty
    """
    OWL_RESTRICTION: Literal[1217]
    """
    http://www.w3.org/2002/07/owl#Restriction
    """
    OWL_ONPROPERTY: Literal[1218]
    """
    http://www.w3.org/2002/07/owl#onProperty
    """
    OWL_ALLVALUESFROM: Literal[1219]
    """
    http://www.w3.org/2002/07/owl#allValuesFrom
    """
    OWL_SOMEVALUESFROM: Literal[1220]
    """
    http://www.w3.org/2002/07/owl#someValuesFrom
    """
    OWL_MINCARDINALITY: Literal[1221]
    """
    http://www.w3.org/2002/07/owl#minCardinality
    """
    OWL_MAXCARDINALITY: Literal[1222]
    """
    http://www.w3.org/2002/07/owl#maxCardinality
    """
    OWL_CARDINALITY: Literal[1223]
    """
    http://www.w3.org/2002/07/owl#cardinality
    """
    OWL_ONTOLOGY: Literal[1224]
    """
    http://www.w3.org/2002/07/owl#Ontology
    """
    OWL_IMPORTS: Literal[1225]
    """
    http://www.w3.org/2002/07/owl#imports
    """
    OWL_VERSIONINFO: Literal[1226]
    """
    http://www.w3.org/2002/07/owl#versionInfo
    """
    OWL_PRIORVERSION: Literal[1227]
    """
    http://www.w3.org/2002/07/owl#priorVersion
    """
    OWL_BACKWARDCOMPATIBLEWITH: Literal[1228]
    """
    http://www.w3.org/2002/07/owl#backwardCompatibleWith
    """
    OWL_INCOMPATIBLEWITH: Literal[1229]
    """
    http://www.w3.org/2002/07/owl#incompatibleWith
    """
    OWL_DEPRECATEDCLASS: Literal[1230]
    """
    http://www.w3.org/2002/07/owl#DeprecatedClass
    """
    OWL_DEPRECATEDPROPERTY: Literal[1231]
    """
    http://www.w3.org/2002/07/owl#DeprecatedProperty
    """
    OWL_ANNOTATIONPROPERTY: Literal[1232]
    """
    http://www.w3.org/2002/07/owl#AnnotationProperty
    """
    OWL_ONTOLOGYPROPERTY: Literal[1233]
    """
    http://www.w3.org/2002/07/owl#OntologyProperty
    """
    OWL_ONEOF: Literal[1234]
    """
    http://www.w3.org/2002/07/owl#oneOf
    """
    OWL_DATARANGE: Literal[1235]
    """
    http://www.w3.org/2002/07/owl#dataRange
    """
    OWL_DISJOINTWITH: Literal[1236]
    """
    http://www.w3.org/2002/07/owl#disjointWith
    """
    OWL_UNIONOF: Literal[1237]
    """
    http://www.w3.org/2002/07/owl#unionOf
    """
    OWL_COMPLEMENTOF: Literal[1238]
    """
    http://www.w3.org/2002/07/owl#complementOf
    """
    OWL_INTERSECTIONOF: Literal[1239]
    """
    http://www.w3.org/2002/07/owl#intersectionOf
    """
    OWL_HASVALUE: Literal[1240]
    """
    http://www.w3.org/2002/07/owl#hasValue
    """
    PKG_HASPART: Literal[2000]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#hasPart
    """
    PKG_MIMETYPE: Literal[2003]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#mimeType
    """
    PKG_PACKAGE: Literal[2004]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Package
    """
    PKG_ELEMENT: Literal[2005]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Element
    """
    PKG_FILE: Literal[2006]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#File
    """
    PKG_METADATAFILE: Literal[2007]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#MetadataFile
    """
    PKG_DOCUMENT: Literal[2008]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/pkg#Document
    """
    ODF_PREFIX: Literal[2100]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/odf#prefix
    """
    ODF_SUFFIX: Literal[2101]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/odf#suffix
    """
    ODF_ELEMENT: Literal[2102]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/odf#Element
    """
    ODF_CONTENTFILE: Literal[2103]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/odf#ContentFile
    """
    ODF_STYLESFILE: Literal[2104]
    """
    http://docs.oasis-open.org/ns/office/1.2/meta/odf#StylesFile
    """
    LO_EXT_SHADING: Literal[2106]
    """
    custom shading color of an annotated text range or metadata field (replacement of the default field shading color)
    
    urn:org:documentfoundation:names:experimental:office:xmlns:loext:1.0odf#shading
    
    **since**
    
        LibreOffice 7.2
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.report.meta
from typing_extensions import Literal
import typing
from ...beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ...container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
if typing.TYPE_CHECKING:
    from .x_function_description import XFunctionDescription as XFunctionDescription_8d8d119b

class XFunctionCategory(XPropertySet_bc180bfa, XIndexAccess_f0910d6d):
    """
    identifies a XFunctionCategory which allows to retrieve the meta data of all supported functions.

    See Also:
        `API XFunctionCategory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1meta_1_1XFunctionCategory.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.report.meta.XFunctionCategory']

    def getFunction(self, position: int) -> 'XFunctionDescription_8d8d119b':
        """
        same as getByIndex.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    @property
    def Name(self) -> str:
        """
        returns the localized category's name.
        """

    @property
    def Number(self) -> int:
        """
        specifies the category number.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..beans.property import Property as Property_8f4e0a76
from ..uno.x_interface import XInterface as XInterface_8f010a43


class OpenCommandArgument(object):
    """
    Struct Class

    The argument for commands like \"open\", \"update\", and \"synchronize\".

    See Also:
        `API OpenCommandArgument <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1OpenCommandArgument.html>`_
    """
    typeName: Literal['com.sun.star.ucb.OpenCommandArgument']

    def __init__(self, Properties: typing.Optional[typing.Tuple[Property_8f4e0a76, ...]] = ..., Mode: typing.Optional[int] = ..., Priority: typing.Optional[int] = ..., Sink: typing.Optional[XInterface_8f010a43] = ...) -> None:
        """
        Constructor

        Arguments:
            Properties (typing.Tuple[Property, ...], optional): Properties value.
            Mode (int, optional): Mode value.
            Priority (int, optional): Priority value.
            Sink (XInterface, optional): Sink value.
        """


    @property
    def Properties(self) -> typing.Tuple[Property_8f4e0a76, ...]:
        """
        The properties, for that the values shall be provided by the DynamicResultSet returned by the command).
        """


    @property
    def Mode(self) -> int:
        """
        A mode.
        
        The value can be one of the OpenMode constants.
        """


    @property
    def Priority(self) -> int:
        """
        The command's priority, in the range 0 (highest) to 65535 (lowest).
        """


    @property
    def Sink(self) -> XInterface_8f010a43:
        """
        The data sink to write the contents into (supporting either com.sun.star.io.XActiveDataSink, com.sun.star.io.XOutputStream or com.sun.star.io.XActiveDataStreamer).
        
        XActiveDataSink and XOutputStream give the caller read-only access to the contents. XActiveDataStreamer offers both read and write access to the contents.
        
        If an XActiveDataSink is supplied, the implementation of the command needs to provide an implementation of an object implementing the interface com.sun.star.io.XInputStream. It is highly recommended that this object also implements the interface com.sun.star.io.XSeekable, if this can be done without wasting resources (i.e. allocating huge memory buffers). The implementation object has to be supplied to the data sink.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sheet
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_sheet_condition import XSheetCondition as XSheetCondition_e1940d19
if typing.TYPE_CHECKING:
    from .validation_alert_style import ValidationAlertStyle as ValidationAlertStyle_2a930f35
    from .validation_type import ValidationType as ValidationType_d6110cce

class TableValidation(XPropertySet_bc180bfa, XSheetCondition_e1940d19):
    """
    Service Class

    represents the data validation settings for a cell or cell range.

    See Also:
        `API TableValidation <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1TableValidation.html>`_
    """
    @property
    def ErrorAlertStyle(self) -> 'ValidationAlertStyle_2a930f35':
        """
        specifies the style of the error message.
        
        This is used only if TableValidation.ShowErrorMessage is set to TRUE.
        """
    @property
    def ErrorMessage(self) -> str:
        """
        specifies the text of the error message.
        
        This is only used if TableValidation.ShowErrorMessage is set to TRUE.
        """
    @property
    def ErrorTitle(self) -> str:
        """
        specifies the title of the window showing the error message.
        
        This is only used if TableValidation.ShowErrorMessage is set to TRUE.
        """
    @property
    def IgnoreBlankCells(self) -> bool:
        """
        specifies if blank cells should be allowed.
        """
    @property
    def InputMessage(self) -> str:
        """
        specifies the text of the input message.
        
        This is only used if TableValidation.ShowInputMessage is set to TRUE.
        """
    @property
    def InputTitle(self) -> str:
        """
        specifies the title of the window showing the input message.
        
        This is only used if TableValidation.ShowInputMessage is set to TRUE.
        """
    @property
    def ShowErrorMessage(self) -> bool:
        """
        specifies if an error message is displayed when invalid data is entered.
        """
    @property
    def ShowInputMessage(self) -> bool:
        """
        specifies if an input message is shown when the cursor is in a cell with these validation settings.
        """
    @property
    def ShowList(self) -> int:
        """
        specifies if the list of possible values should be shown on the cell and how.
        
        See also TableValidationVisibility
        """
    @property
    def Type(self) -> 'ValidationType_d6110cce':
        """
        specifies the type of validation.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal


class ColorSpaceType(object):
    """
    Const

    Categories for color spaces.

    See Also:
        `API ColorSpaceType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1ColorSpaceType.html>`_
    """
    DEVICE_COLOR: Literal[0]
    """
    Unspecified device color space - use conversion functions to convert to standard color spaces.
    """
    GREY: Literal[1]
    """
    Grey-value color space.
    
    Use this for monochrome images.
    """
    RGB: Literal[2]
    """
    RGB color space.
    """
    CMYK: Literal[3]
    """
    CMYK color space.
    
    See Wikipedia for a thorough explanation.
    """
    CMYKOG: Literal[4]
    """
    CMYKOG color space.
    
    See Wikipedia for a thorough explanation.
    """
    CIEXYZ: Literal[5]
    """
    Standard CieXYZ color space.
    
    See Wikipedia for a thorough explanation.
    """
    CIELAB: Literal[6]
    """
    Standard CieLab color space.
    
    See Wikipedia for a thorough explanation. Preferable over CIEXYZ if perceptual uniformity is an issue.
    """
    SRGB: Literal[7]
    """
    Standard sRGB color space.
    
    See Wikipedia for a thorough explanation.
    """
    HSV: Literal[8]
    """
    HSV color space.
    
    Hue saturation value. See Wikipedia for a thorough explanation.
    """
    HSL: Literal[9]
    """
    HSL color space.
    
    Hue saturation lightness. See Wikipedia for a thorough explanation
    """
    YCBCR: Literal[10]
    """
    YCbCr color space.
    
    See Wikipedia for a thorough explanation. This color space is common for digital video.
    """
    INDEXED: Literal[11]
    """
    Indexed color space.
    
    The color components of this color space are in fact indices into a color map.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from ..document.settings import Settings as Settings_b2bc0bb8
from .print_settings import PrintSettings as PrintSettings_bea20c2b

class DocumentSettings(Settings_b2bc0bb8, PrintSettings_bea20c2b):
    """
    Service Class

    describes properties that apply to the whole text document.
    
    **since**
    
        OOo 2.0

    See Also:
        `API DocumentSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html>`_
    """
    @property
    def AddParaSpacingToTableCells(self) -> bool:
        """
        specifies if paragraph and table spacing is added at the bottom of table cells
        
        This property controls, if the spacing of the last paragraph respectively table of a table cell is added at the bottom of this table cells If TRUE (default for documents since OpenOffice.org 2.0), the spacing of the last paragraph respectively table of a table cell is added at the bottom of this table cell. If FALSE (typically for documents till OpenOffice.org 1.1), the spacing of the last paragraph respectively table of a table cell isn't added at the bottom of this table cell.
        
        **since**
        
            OOo 2.0
        """
    @property
    def AddParaTableSpacing(self) -> bool:
        """
        specifies if spacing between paragraphs and tables is to be added.
        
        If between two paragraphs, two tables, or a paragraph and a table, you have defined spacing above and below each object, usually only the larger one of the two spaces is used. If the spacing between the objects are to be added this property has to be TRUE.
        """
    @property
    def AddParaTableSpacingAtStart(self) -> bool:
        """
        specifies if top paragraph spacing is applied to paragraphs on the first page of text documents.
        
        If TRUE, the paragraph or table spacing to the top will also be effective at the beginning of a page or column if the paragraph or table is positioned on the first page of the document. The same applies for a page break.
        """
    @property
    def AlignTabStopPosition(self) -> bool:
        """
        specifies the alignment of tab stops in text documents.
        
        If TRUE centered and right-aligned paragraphs containing tabs are formatted as a whole in the center or aligned to the right. If FALSE, only the text to the right of the last tab, for example, is aligned to the right, while the text to the left remains where it is.
        """
    @property
    def ChartAutoUpdate(self) -> bool:
        """
        specifies if charts in text documents are updated automatically.
        
        This has no effect if \"FieldAutoUpdate\" is FALSE.
        """
    @property
    def ConsiderTextWrapOnObjPos(self) -> bool:
        """
        specifies if the text wrap of floating screen objects are considered in a specified way in the positioning algorithm.
        
        This property controls how floating screen objects (Writer fly frames and drawing objects) are positioned. If TRUE, the object positioning algorithm will consider the text wrap style, set at the floating screen object. The attribute BaseFrameProperties.WrapInfluenceOnPosition specifies how the text wrap is considered. If FALSE (default value), the former object positioning algorithm (known from OpenOffice.org 1.1) is applied.
        
        **since**
        
            OOo 2.0
        """
    @property
    def IsLabelDocument(self) -> bool:
        """
        specifies if the document has been created as a label document.
        
        This property indicates that the document contains multiple text frames and that the content of one frame is duplicated into the other frames by internally linked text sections.
        """
    @property
    def MathBaselineAlignment(self) -> bool:
        """
        specifies if Math objects should automatically vertically aligned to match the baseline of the surrounding text.
        
        If activated formula object that are anchored 'As Character' will be vertically aligned to have their baseline match with the one from the text.
        
        **since**
        
            OOo 3.4
        """
    @property
    def SaveGlobalDocumentLinks(self) -> bool:
        """
        specifies if the contents of links in the global document are saved or not.
        
        This property applies only for master documents.
        
        Note: This name is a bit misleading, it should be something like SaveLinkedDocumentContent.
        """
    @property
    def UseFormerLineSpacing(self) -> bool:
        """
        specifies if the former (till OpenOffice.org 1.1) or the new line spacing formatting is applied.
        
        This property controls how a set line spacing at a paragraph influences the formatting of the text lines and the spacing between paragraphs. If TRUE, the formatting till OpenOffice.org 1.1 is applied. This means, that a proportional line spacing is applied above and below a text line and that the maximum of the line spacing value between two paragraphs is added respectively reckoned up with the paragraph spacing (adding or reckoning up is controlled by document option AddParaTableSpacing). If FALSE (default for documents since OpenOffice.org 2.0), a proportional line spacing is only applied below a text line and it's always added to the paragraph spacing between two paragraphs.
        
        **since**
        
            OOo 2.0
        """
    @property
    def UseFormerObjectPositioning(self) -> bool:
        """
        specifies if the former (till OpenOffice.org 1.1) or the new object positioning is applied.
        
        This property controls how floating screen objects (Writer fly frames and drawing objects are positioned. If TRUE, the object positioning till OpenOffice.org 1.1 is applied. This means, that the top of a paragraph, at which a floating screen object orients its vertical position, includes the lower spacing and the line spacing of the previous paragraph. If FALSE (default for documents since OpenOffice.org 2.0), the top of a paragraph, at which a floating screen object orients its vertical position, doesn't include the lower spacing and the line spacing of the previous paragraph.
        
        **since**
        
            OOo 2.0
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from .x_controller import XController as XController_b00e0b8f
if typing.TYPE_CHECKING:
    from ..awt.x_window import XWindow as XWindow_713b0924
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..ui.x_sidebar_provider import XSidebarProvider as XSidebarProvider_c69c0c43

class XController2(XController_b00e0b8f):
    """
    extends the XController interface
    
    **since**
    
        OOo 3.0

    See Also:
        `API XController2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XController2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XController2']

    def getSidebar(self) -> 'XSidebarProvider_c69c0c43':
        """
        get the sidebar if exists
        
        **since**
        
            LibreOffice 5.1
        """
    @property
    def CreationArguments(self) -> 'typing.Tuple[PropertyValue_c9610c73, ...]':
        """
        denotes the arguments used to create the instance.
        
        Usually, controllers are created via XModel2.createViewController(), where the caller can pass not only a controller name, but also arguments parameterizing the to-be-created instance. Those arguments used at creation time can subsequently be retrieved using the CreationArguments member.
        """

    @property
    def ComponentWindow(self) -> 'XWindow_713b0924':
        """
        denotes the \"root window\" of the controller.
        
        If the controller is plugged into a frame, this window acts as the frame's ComponentWindow.
        """

    @property
    def ViewControllerName(self) -> str:
        """
        specifies the view name of the controller.
        
        A view name is a logical name, which can be used to create views of the same type. The name is meaningful only in conjunction with XModel2.createViewController()
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.animations
from typing_extensions import Literal
"""
Const


See Also:
    `API TransitionType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionType.html>`_
"""
BARWIPE: Literal[1]
BOXWIPE: Literal[2]
FOURBOXWIPE: Literal[3]
BARNDOORWIPE: Literal[4]
DIAGONALWIPE: Literal[5]
BOWTIEWIPE: Literal[6]
MISCDIAGONALWIPE: Literal[7]
VEEWIPE: Literal[8]
BARNVEEWIPE: Literal[9]
ZIGZAGWIPE: Literal[10]
BARNZIGZAGWIPE: Literal[11]
IRISWIPE: Literal[12]
TRIANGLEWIPE: Literal[13]
ARROWHEADWIPE: Literal[14]
PENTAGONWIPE: Literal[15]
HEXAGONWIPE: Literal[16]
ELLIPSEWIPE: Literal[17]
EYEWIPE: Literal[18]
ROUNDRECTWIPE: Literal[19]
STARWIPE: Literal[20]
MISCSHAPEWIPE: Literal[21]
CLOCKWIPE: Literal[22]
PINWHEELWIPE: Literal[23]
SINGLESWEEPWIPE: Literal[24]
FANWIPE: Literal[25]
DOUBLEFANWIPE: Literal[26]
DOUBLESWEEPWIPE: Literal[27]
SALOONDOORWIPE: Literal[28]
WINDSHIELDWIPE: Literal[29]
SNAKEWIPE: Literal[30]
SPIRALWIPE: Literal[31]
PARALLELSNAKESWIPE: Literal[32]
BOXSNAKESWIPE: Literal[33]
WATERFALLWIPE: Literal[34]
PUSHWIPE: Literal[35]
SLIDEWIPE: Literal[36]
FADE: Literal[37]
RANDOMBARWIPE: Literal[38]
CHECKERBOARDWIPE: Literal[39]
DISSOLVE: Literal[40]
BLINDSWIPE: Literal[41]
RANDOM: Literal[42]
ZOOM: Literal[43]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.linguistic2
# Libre Office Version: 7.2
from typing_extensions import Literal
from ..lang.event_object import EventObject as EventObject_a3d70b03
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class LinguServiceEvent(EventObject_a3d70b03):
    """
    Struct Class

    represents a linguistic service event.
    
    This type of event may be broadcast by a spell checker or hyphenator service implementation to inform its listeners (clients) that the results of previous function calls may be different now. It is possible to suggest that hyphenation should be done again and/or the spelling of previously incorrect or correct words should be checked again.

    See Also:
        `API LinguServiceEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1linguistic2_1_1LinguServiceEvent.html>`_
    """
    typeName: Literal['com.sun.star.linguistic2.LinguServiceEvent']

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = ..., nEvent: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            nEvent (int, optional): nEvent value.
        """


    @property
    def nEvent(self) -> int:
        """
        The type of event.
        
        The value may be combined via logical OR from those values defined in com.sun.star.linguistic2.LinguServiceEventFlags
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdbcx
from ..sdbc.driver import Driver as Driver_70e70910
from .x_create_catalog import XCreateCatalog as XCreateCatalog_d3410c83
from .x_data_definition_supplier import XDataDefinitionSupplier as XDataDefinitionSupplier_5632104b
from .x_drop_catalog import XDropCatalog as XDropCatalog_bb040bc4

class Driver(Driver_70e70910, XCreateCatalog_d3410c83, XDataDefinitionSupplier_5632104b, XDropCatalog_bb040bc4):
    """
    Service Class

    extends the service com.sun.star.sdbc.Driver by beans for data definition.
    
    This service is optional for each driver. Its purpose is to define a common way for database definition, as the DDL differs between most DBMS.
    
    Definition and deletion of database catalogs can't be defined in a common manner for DBMS, but it should be possible to hide much of the complexity of creation and deletion of catalogs. Each driver could provide methods to cover these tasks.

    See Also:
        `API Driver <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbcx_1_1Driver.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .color_component import ColorComponent as ColorComponent_e4c0e78
    from .x_color_space import XColorSpace as XColorSpace_e3940d09

class XBitmapPalette(XInterface_8f010a43):
    """
    Interface to access the palette of a color-indexed bitmap.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XBitmapPalette <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XBitmapPalette.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rendering.XBitmapPalette']

    def getColorSpace(self) -> 'XColorSpace_e3940d09':
        """
        Query associated color space.
        """
    def getIndex(self, entry: 'typing.Tuple[ColorComponent_e4c0e78, ...]', nIndex: int) -> bool:
        """
        Request the color for the given palette entry.

        * ``entry`` is an out direction argument.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getNumberOfEntries(self) -> int:
        """
        Request the number of palette entries available.
        """
    def setIndex(self, color: 'typing.Tuple[ColorComponent_e4c0e78, ...]', transparency: bool, nIndex: int) -> bool:
        """
        Set the color for the given palette entry.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.script
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
    from .x_all_listener import XAllListener as XAllListener_c91b0c54

class XEventAttacher(XInterface_8f010a43):
    """
    makes it possible to attach script events given by a sequence of ScriptEventDescriptor structures to a given interface.

    See Also:
        `API XEventAttacher <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XEventAttacher.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.script.XEventAttacher']

    def attachListener(self, xTarget: 'XInterface_8f010a43', xAllListener: 'XAllListener_c91b0c54', aHelper: object, aListenerType: str, aAddListenerParam: str) -> 'XEventListener_c7230c4a':
        """
        registers the given \"AllListener\" object as a listener at the given interface by creating a suitable listener adapter and calling the \"addListener\" method corresponding to the \"ListenerType\".

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.beans.IntrospectionException: ``IntrospectionException``
            com.sun.star.script.CannotCreateAdapterException: ``CannotCreateAdapterException``
            com.sun.star.lang.ServiceNotRegisteredException: ``ServiceNotRegisteredException``
        """
    def attachSingleEventListener(self, xTarget: 'XInterface_8f010a43', xAllListener: 'XAllListener_c91b0c54', aHelper: object, aListenerType: str, aAddListenerParam: str, aEventMethod: str) -> 'XEventListener_c7230c4a':
        """
        registers an object as a listener at the given interface by creating a suitable listener adapter and calling the method which corresponds to the listener type.
        
        Only the event corresponding to the given event method will be delegated to xAllListener.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.beans.IntrospectionException: ``IntrospectionException``
            com.sun.star.script.CannotCreateAdapterException: ``CannotCreateAdapterException``
            com.sun.star.lang.ServiceNotRegisteredException: ``ServiceNotRegisteredException``
        """
    def removeListener(self, xTarget: 'XInterface_8f010a43', aListenerType: str, aRemoveListenerParam: str, xToRemoveListener: 'XEventListener_c7230c4a') -> None:
        """
        removes a listener object as a listener from the given interface.
        
        This method can and should be used as a contrary method to the two attach methods.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.beans.IntrospectionException: ``IntrospectionException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.bridge
from .x_bridge import XBridge as XBridge_8e4e0a1a
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca

class Bridge(XBridge_8e4e0a1a, XComponent_98dc0ab5, XInitialization_d46c0cca):
    """
    Service Class

    This meta service allows the bridgefactory service to instantiate an interprocess bridge using a certain transfer protocol.
    
    Components, that support a certain protocol, must have at least two service names:
    
    The protocol name should be written as common servicenames, first letter is a capital letter, the rest in small letters postfixed by Bridge (e.g.: com.sun.star.bridge.UrpBridge would be correct servicename for the \"urp\" protocol). However, the protocol names are compared case insensitive. If there exist two services supporting the same protocol, it is arbitrary which one is chosen, so this should be omitted.

    See Also:
        `API Bridge <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1Bridge.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..lang.locale import Locale as Locale_70d308fa


class NativeNumberXmlAttributes(object):
    """
    Struct Class

    Attributes describing a native number mode for a specific locale, stored in XML file format.
    
    Used with XNativeNumberSupplier.convertToXmlAttributes() and XNativeNumberSupplier.convertFromXmlAttributes()
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API NativeNumberXmlAttributes <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1NativeNumberXmlAttributes.html>`_
    """
    typeName: Literal['com.sun.star.i18n.NativeNumberXmlAttributes']

    def __init__(self, Locale: typing.Optional[Locale_70d308fa] = ..., Format: typing.Optional[str] = ..., Style: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Locale (Locale, optional): Locale value.
            Format (str, optional): Format value.
            Style (str, optional): Style value.
        """


    @property
    def Locale(self) -> Locale_70d308fa:
        """
        The locale of the native number representation.
        """


    @property
    def Format(self) -> str:
        """
        The number \"1\" expressed as a native number string.
        """


    @property
    def Style(self) -> str:
        """
        The type of the number string, for example, \"short\" or \"medium\" or \"long\".
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.script
from typing_extensions import Literal
import typing
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03
    from .finish_engine_event import FinishEngineEvent as FinishEngineEvent_d540e56
    from .interrupt_engine_event import InterruptEngineEvent as InterruptEngineEvent_3e1d0fc2

class XEngineListener(XEventListener_c7230c4a):
    """
    makes it possible to receive events from a scripting engine.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XEngineListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XEngineListener.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.script.XEngineListener']

    def finished(self, Evt: 'FinishEngineEvent_d540e56') -> None:
        """
        gets fired when the script execution has finished.
        """
    def interrupt(self, Evt: 'InterruptEngineEvent_3e1d0fc2') -> None:
        """
        gets fired when an interrupt occurs during the script execution.
        
        If you call the method, the execution stops. So in this situation, the stack and variable values are still available by using the appropriate XDebugging methods.
        """
    def running(self, Evt: 'EventObject_a3d70b03') -> None:
        """
        gets fired when the script gets into execution state.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ui.dialogs
from typing_extensions import Literal
import typing
from .x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1
if typing.TYPE_CHECKING:
    from ...awt.x_window import XWindow as XWindow_713b0924
    from .x_wizard_page import XWizardPage as XWizardPage_ed7c0d3d

class XWizard(XExecutableDialog_450f0fa1):
    """
    is the main interface implemented by the Wizard services.
    
    A wizard is a dialog which guides the user through a number of tasks (usually input of data), which the user can accomplish either sequentially or out-of-order. For this, a wizard is comprised of a number of tab pages, each page representing a single step.
    
    Sequential navigation in a wizard is done via a Next and a Back button. Non-sequential navigation is done via a roadmap, which is displayed on the left hand side of the wizard dialog, lists all available steps, and allows jumping to a certain step (where the creator of the wizard can restrict the available steps depending on the current situation in the wizard, see below).
    
    A sequence of steps in a wizard dialog is called a path. A given wizard can support one or multiple paths, which are declared at the time of construction of the wizard.
    
    In the simplest case, where the wizard supports only one path, all available steps are displayed in the roadmap, and the user can simply travel through them as desired.
    
    If the wizard is more complex, and supports multiple paths, things become more complicated. In a given situation of the wizard, where the user is at step k of the current path, the potential or conflicting paths are those whose first k steps are the same as in the current path. Obviously, there's at least one potential path in every situation: the current one. If there is more than one, then the future steps in the dialog are not finally decided. In such a case, the roadmap will display future steps up to the point where the potential paths diverge, and then an item ... indicating that the order of steps is undecided.
    
    An XWizardController can declare a certain path as active path by calling the activatePath() method. Usually, this is done depending on user input. For instance, your wizard could have radio buttons on the first page which effectively decide about which path to take in the wizard.
    
    Single steps in the wizard can be freely enabled and disabled, using the enablePage() method. Disabled pages are skipped during sequential traveling, and not selectable in the roadmap.
    
    The state of the Next button in the dialog will be automatically maintained in most situations, depending on the results of calls to the XWizardController.canAdvance() and XWizardPage.canAdvance() methods. More sophisticated wizard logic, however, will need manual calls to the enableButton() method. Also, the Finish button needs to be maintained by the wizard's controller, too, as it cannot be decided generically in which situations it should be enabled or disabled.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XWizard <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XWizard.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.dialogs.XWizard']

    def activatePath(self, PathIndex: int, Final: bool) -> None:
        """
        activates a path
        
        If the wizard has been created with multiple paths of control flow, then this method allows switching to another path.
        
        You can only activate a path which shares the first k pages with the path which is previously active (if any), where k is the index of the current page within the current path.
        
        Example: Say you have paths, (0,1,2,5) and (0,1,4,5) (with the numbers denoting page IDs). This means that after page 1, you either continue with page 2 or state 4,and after this, you finish in state 5.
        Now if the first path is active, and your current state is 1, then you can easily switch to the second path, since both paths start with (0,1).
        However, if your current state is 2, then you can not switch to the second path anymore.
        
        If TRUE, the path will be completely activated, even if it is a conflicting path (i.e. there is another path which shares the first k states with the to-be-activated path.)
        
        If FALSE, then the new path is checked for conflicts with other paths. If such conflicts exists, the path is not completely activated, but only up to the point where it does not conflict.
        
        In this latter case, you need another activatePath method (usually triggered by the user doing some decisions and entering some data on the reachable pages) before the wizard can actually be finished.
        
        With the paths in the example above, if you activate the second path, then only steps 0 and 1 are activated, since they are common to both paths. Steps 2, 4, and 5 are not reachable, yet.

        Raises:
            : ````
            com.sun.star.util.InvalidStateException: ``InvalidStateException``
        """
    def advanceTo(self, PageId: int) -> bool:
        """
        advances to the given page, if possible.
        
        Calling this method is equivalent to the user repeatedly pressing the Next button, until the given page is reached. Consequently, the method will fail if one of the intermediate pages does not allow advancing to the next page.
        """
    def enableButton(self, WizardButton: int, Enable: bool) -> None:
        """
        enables or disables a certain button in the wizard
        
        Normally, you will want to use this method for the Finish button only: The Next and Back buttons are usually maintained automatically, the Help and Cancel buttons are unlikely to ever being disabled.
        """
    def enablePage(self, PageID: int, Enable: bool) -> None:
        """
        enables or disables the given page
        
        You can use this method when not all pages of your wizard are necessarily needed in all cases. For instance, assume that your first wizard page contains a check box, which the user can check to enter additional data. If you place this data on the second page, then you will want to enable this second page if and only if the checkbox is checked.
        
        If a page is disabled, it can reached neither by clicking the respective item in the wizard's roadmap, nor by sequential traveling. Still, the page's item is displayed in the roadmap, though disabled.

        Raises:
            : ````
            com.sun.star.util.InvalidStateException: ``InvalidStateException``
        """
    def getCurrentPage(self) -> 'XWizardPage_ed7c0d3d':
        """
        provides access to the current page of the wizard
        """
    def goBackTo(self, PageId: int) -> bool:
        """
        goes back to the given page, if possible.
        
        Calling this method is equivalent to the user repeatedly pressing the Back button, until the given page is reached.
        """
    def setDefaultButton(self, WizardButton: int) -> None:
        """
        sets a button in the wizard as default button
        
        In general, the default button in a wizard is the one which is activated when the user presses the return key while the focus is in a control which does not handle this key itself (such as ordinary input controls).
        
        You can use this method, for instance, to make the Next button the default button on all pages except the last one, where Finish should be defaulted.
        """
    def travelNext(self) -> bool:
        """
        travels to the next page, if possible
        
        Calling this method is equivalent to the user pressing the Next button in the wizard. Consequently, the method will fail if in the current state of the wizard, it is not allowed to advance to a next page.
        """
    def travelPrevious(self) -> bool:
        """
        travels to the next page, if possible
        
        Calling this method is equivalent to the user pressing the Back button in the wizard.
        """
    def updateTravelUI(self) -> None:
        """
        updates the wizard elements which are related to traveling.
        
        For instance, the Next button is disabled if the current page's XWizardPage.canAdvance() method returns FALSE.
        
        You usually call this method from within a wizard page whose state changed in a way that it affects the user's ability to reach other pages.
        """
    @property
    def DialogWindow(self) -> 'XWindow_713b0924':
        """
        """

    @property
    def HelpURL(self) -> str:
        """
        is the help URL of the wizard's main window.
        """


